@@ -38,6 +38,7 @@ const ContextMenu = imports.contextMenu;
 const PlaceStore = imports.placeStore;
 const Utils = imports.utils;
 const Config = imports.config;
+const ZoomControl = imports.zoomControl;
 
 const _ = imports.gettext.gettext;
 
@@ -62,15 +63,13 @@ const MainWindow = new Lang.Class({
                                                     'window-content',
                                                     'search-entry',
                                                     'search-completion']);
-        let grid = ui.windowContent;
         this._searchEntry = ui.searchEntry;
         this._searchCompletion = ui.searchCompletion;
         this.window = ui.appWindow;
         this.window.application = app;
 
-        this._mapOverlay = new Gtk.Overlay({ visible: true });
-        this.mapView = new MapView.MapView(this._mapOverlay);
-        this._mapOverlay.add(this.mapView);
+        this.mapView = new MapView.MapView();
+        ui.windowContent.add(this.mapView);
 
         this.mapView.gotoUserLocation(false);
 
@@ -82,11 +81,9 @@ const MainWindow = new Lang.Class({
         this._initSignals();
         this._restoreWindowGeometry();
 
-        this._mapOverlay.add_overlay(this._searchPopup);
+        ui.windowContent.add_overlay(new ZoomControl.ZoomControl(this.mapView));
 
-        grid.add(this._mapOverlay);
-
-        grid.show_all();
+        ui.windowContent.show_all();
     },
 
     _initPlaces: function() {
@@ -100,7 +97,7 @@ const MainWindow = new Lang.Class({
     },
 
     _initSearchWidgets: function() {
-        this._searchPopup = new SearchPopup.SearchPopup(10);
+        this._searchPopup = new SearchPopup.SearchPopup(this._searchEntry, 10);
 
         let model = new Gtk.ListStore();
         model.set_column_types([GdkPixbuf.Pixbuf,
